@@ -3,7 +3,13 @@
 #' Performs k-fold cross validation for lasso-, MCP-, or SCAD-penalized
 #'  linear mixed models over a grid of values for the regularization parameter `lambda`.
 #'
-#' @param design          Design matrix object (as created by `create_design()`) or a string with the file path to a design object (the file path must end in '.rds').
+#' @param design          The first argument must be one of three things:
+#'                          (1) `plmm_design` object (as created by `create_design()`)
+#'                          (2) a string with the file path to a design object (the file path must end in '.rds')
+#'                          (3) a `matrix` or `data.frame` object representing the design matrix of interest
+#' @param y               Optional: In the case where `design` is a `matrix` or `data.frame`, the user must also supply
+#'                        a numeric outcome vector as the `y` argument. In this case, `design` and `y` will be passed
+#'                        internally to `create_design(X = design, y = y)`.
 #' @param K               Similarity matrix used to rotate the data. This should either be (1) a known matrix that reflects the covariance of y, (2) an estimate (Default is \eqn{\frac{1}{p}(XX^T)}), or (3) a list with components 'd' and 'u', as returned by choose_k().
 #' @param diag_K          Logical: should K be a diagonal matrix? This would reflect observations that are unrelated, or that can be treated as unrelated. Defaults to FALSE.
 #'                        Note: plmm() does not check to see if a matrix is diagonal. If you want to use a diagonal K matrix, you must set diag_K = TRUE.
@@ -66,7 +72,7 @@
 #' @export
 #'
 #' @examples
-#' admix_design <- create_design(X = admix$X, outcome_col = admix$y)
+#' admix_design <- create_design(X = admix$X, y = admix$y)
 #' cv_fit <- cv_plmm(design = admix_design, return_fit = TRUE)
 #' print(summary(cv_fit))
 #' plot(cv_fit)
@@ -76,6 +82,7 @@
 #'
 #'
 cv_plmm <- function(design,
+                    y = NULL,
                     K = NULL,
                     diag_K = NULL,
                     eta_star = NULL,
@@ -126,6 +133,24 @@ cv_plmm <- function(design,
                                          save_rds,
                                          "./cv-plmm"))
 
+  # create a design if needed -------------
+  if (inherits(design, "data.frame") | inherits(design, 'matrix')) {
+    # error check: if 'design' is matrix/data.frame, user must specify 'y'
+    if (is.null(y)) {
+      stop("If you supply a matrix or data frame as 'design', you
+                         must also specify a numeric vector as the outcome of your
+                         model to the 'y' argument.")
+    }
+
+    design <- create_design_in_memory(X = design, y = y)
+
+
+  } else {
+    if (!is.null(y)) stop("If you are supplying a plmm_design object or filepath to
+                          the 'design' argument, that design already has a 'y' --
+                          please do not specify a 'y' argument here in plmm()")
+  }
+
   # run data checks ------------------------------
   checked_data <- plmm_checks(design = design,
                               K = K,
